==> jc-1.4.0.tar.gz: javax/xml/datatype/DatatypeConfigurationException.h <==
// public class javax.xml.datatype.DatatypeConfigurationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 8a8b42ea938cd235 javax_xml_datatype_DatatypeConfigurationException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_xml_datatype_DatatypeConfigurationException_H_
#define _JC_javax_xml_datatype_DatatypeConfigurationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_javax_xml_datatype_DatatypeConfigurationException$sub_refs	_jc_javax_xml_datatype_DatatypeConfigurationException$sub_refs;
typedef struct _jc_javax_xml_datatype_DatatypeConfigurationException$sub_nonrefs	_jc_javax_xml_datatype_DatatypeConfigurationException$sub_nonrefs;
typedef struct _jc_javax_xml_datatype_DatatypeConfigurationException$refs	_jc_javax_xml_datatype_DatatypeConfigurationException$refs;
typedef struct _jc_javax_xml_datatype_DatatypeConfigurationException$nonrefs	_jc_javax_xml_datatype_DatatypeConfigurationException$nonrefs;
typedef struct _jc_javax_xml_datatype_DatatypeConfigurationException$object	_jc_javax_xml_datatype_DatatypeConfigurationException$object;

typedef const struct _jc_javax_xml_datatype_DatatypeConfigurationException$vmethods	_jc_javax_xml_datatype_DatatypeConfigurationException$vmethods;
typedef const struct _jc_javax_xml_datatype_DatatypeConfigurationException$vtable	_jc_javax_xml_datatype_DatatypeConfigurationException$vtable;
typedef const struct _jc_javax_xml_datatype_DatatypeConfigurationException$vtype	_jc_javax_xml_datatype_DatatypeConfigurationException$vtype;

// Constructors
extern void _jc_javax_xml_datatype_DatatypeConfigurationException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConfigurationException$object *);
extern void _jc_javax_xml_datatype_DatatypeConfigurationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConfigurationException$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_xml_datatype_DatatypeConfigurationException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConfigurationException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *);
extern void _jc_javax_xml_datatype_DatatypeConfigurationException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConfigurationException$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods structure
struct _jc_javax_xml_datatype_DatatypeConfigurationException$vmethods {
};

// Vtable
struct _jc_javax_xml_datatype_DatatypeConfigurationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_xml_datatype_DatatypeConfigurationException$vmethods	javax_xml_datatype_DatatypeConfigurationException;
};

// Vtype
struct _jc_javax_xml_datatype_DatatypeConfigurationException$vtype {
	_jc_type			type;
	_jc_javax_xml_datatype_DatatypeConfigurationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_datatype_DatatypeConfigurationException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_datatype_DatatypeConfigurationException$refs {
    _jc_javax_xml_datatype_DatatypeConfigurationException$sub_refs	javax_xml_datatype_DatatypeConfigurationException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_datatype_DatatypeConfigurationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_datatype_DatatypeConfigurationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_xml_datatype_DatatypeConfigurationException$sub_nonrefs	javax_xml_datatype_DatatypeConfigurationException;
};

// Object instance structure
struct _jc_javax_xml_datatype_DatatypeConfigurationException$object {
	_jc_javax_xml_datatype_DatatypeConfigurationException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_datatype_DatatypeConfigurationException$vtype	*vtype;
	_jc_javax_xml_datatype_DatatypeConfigurationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_datatype_DatatypeConfigurationException$vtype _jc_javax_xml_datatype_DatatypeConfigurationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_datatype_DatatypeConfigurationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_datatype_DatatypeConfigurationException$class_object;

#endif	/* _JC_javax_xml_datatype_DatatypeConfigurationException_H_ */

==> jc-1.4.6.tar.gz: javax/xml/datatype/DatatypeConfigurationException.h <==
// public class javax.xml.datatype.DatatypeConfigurationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 8a8b42ea938cd235 javax_xml_datatype_DatatypeConfigurationException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_xml_datatype_DatatypeConfigurationException_H_
#define _JC_javax_xml_datatype_DatatypeConfigurationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_javax_xml_datatype_DatatypeConfigurationException$sub_refs	_jc_javax_xml_datatype_DatatypeConfigurationException$sub_refs;
typedef struct _jc_javax_xml_datatype_DatatypeConfigurationException$sub_nonrefs	_jc_javax_xml_datatype_DatatypeConfigurationException$sub_nonrefs;
typedef struct _jc_javax_xml_datatype_DatatypeConfigurationException$refs	_jc_javax_xml_datatype_DatatypeConfigurationException$refs;
typedef struct _jc_javax_xml_datatype_DatatypeConfigurationException$nonrefs	_jc_javax_xml_datatype_DatatypeConfigurationException$nonrefs;
typedef struct _jc_javax_xml_datatype_DatatypeConfigurationException$object	_jc_javax_xml_datatype_DatatypeConfigurationException$object;

typedef const struct _jc_javax_xml_datatype_DatatypeConfigurationException$vmethods	_jc_javax_xml_datatype_DatatypeConfigurationException$vmethods;
typedef const struct _jc_javax_xml_datatype_DatatypeConfigurationException$vtable	_jc_javax_xml_datatype_DatatypeConfigurationException$vtable;
typedef const struct _jc_javax_xml_datatype_DatatypeConfigurationException$vtype	_jc_javax_xml_datatype_DatatypeConfigurationException$vtype;

// Constructors
extern void _jc_javax_xml_datatype_DatatypeConfigurationException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConfigurationException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_datatype_DatatypeConfigurationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConfigurationException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_datatype_DatatypeConfigurationException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConfigurationException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_datatype_DatatypeConfigurationException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConfigurationException$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_xml_datatype_DatatypeConfigurationException$vmethods {
};

// Vtable
struct _jc_javax_xml_datatype_DatatypeConfigurationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_xml_datatype_DatatypeConfigurationException$vmethods	javax_xml_datatype_DatatypeConfigurationException;
};

// Vtype
struct _jc_javax_xml_datatype_DatatypeConfigurationException$vtype {
	_jc_type			type;
	_jc_javax_xml_datatype_DatatypeConfigurationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_datatype_DatatypeConfigurationException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_datatype_DatatypeConfigurationException$refs {
    _jc_javax_xml_datatype_DatatypeConfigurationException$sub_refs	javax_xml_datatype_DatatypeConfigurationException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_datatype_DatatypeConfigurationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_datatype_DatatypeConfigurationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_xml_datatype_DatatypeConfigurationException$sub_nonrefs	javax_xml_datatype_DatatypeConfigurationException;
};

// Object instance structure
struct _jc_javax_xml_datatype_DatatypeConfigurationException$object {
	_jc_javax_xml_datatype_DatatypeConfigurationException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_datatype_DatatypeConfigurationException$vtype	*vtype;
	_jc_javax_xml_datatype_DatatypeConfigurationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_datatype_DatatypeConfigurationException$vtype _jc_javax_xml_datatype_DatatypeConfigurationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_datatype_DatatypeConfigurationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_datatype_DatatypeConfigurationException$class_object;

#endif	/* _JC_javax_xml_datatype_DatatypeConfigurationException_H_ */
